@@ -63,6 +63,17 @@ puts nodeinfo.to_json""" % (env, tier)
         info = json.loads(output)
         return info
 
+    def tiers(self, environment):
+        output = Fork.check_output(["knife", "search", "node", "chef_environment:%s" % environment,
+                                    "-a", "qubole_tier", "--format", "json"], stderr=None)
+        info = json.loads(output)
+        tiers = set()
+        for n in info["rows"]:
+            #if n.has_key("qubole_tier") and n["qubole_tier"] is not None:
+            if n["qubole_tier"] is not None:
+                tiers.add(n["qubole_tier"])
+        return tiers
+
     def nodes(self, environment):
         output = Fork.check_output(["knife", "node", "list", "-E", environment, "-f", "json"], stderr=None)
         info = json.loads(output)
@@ -126,16 +137,17 @@ puts nodeinfo.to_json""" % (env, tier)
         stdin, stdout, stderr = shell.exec_command(cmd)
         return stdout.read()
 
-    def remove_node(self, node, cw_obj):
+    def remove_node(self, node, cw_obj=None):
         logging.info("Found dead node: " + str(node))
         output = Fork.check_output(["knife", "node", "delete", node, "--yes"], stderr=None)
         print output
         output = Fork.check_output(["knife", "client", "delete", node, "--yes"], stderr=None)
         print output
-        alarms = cw_obj.describe_alarms(alarm_name_prefix=node)
-        logging.debug("Alarms for node: " + str(node) + " found = " + str(len(alarms)))
-        for a in alarms:
-            a.delete()
+        if cw_obj != None:
+            alarms = cw_obj.describe_alarms(alarm_name_prefix=node)
+            logging.debug("Alarms for node: " + str(node) + " found = " + str(len(alarms)))
+            for a in alarms:
+                a.delete()
 
     def reap_instances(self, args):
         if args.environment == "development" or args.environment == "_default":
